==> react-molecule-select-1.6.0.tgz: package/lib/hoc/withSelectUI.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _createClass from "@babel/runtime/helpers/createClass";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeSelect-inputSelect";
var CLASS_CONTAINER = BASE_CLASS + "-container";
var CLASS_ARROW = BASE_CLASS + "-arrow";
var CLASS_ARROW_DOWN = CLASS_ARROW + "--down";
var CLASS_ARROW_UP = CLASS_ARROW + "--up";
export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(WithSelectUI, _Component);

    function WithSelectUI() {
      return _Component.apply(this, arguments) || this;
    }

    var _proto = WithSelectUI.prototype;

    _proto.render = function render() {
      /* eslint-disable react/prop-types */
      var _this$props = this.props,
          onClick = _this$props.onClick,
          iconArrow = _this$props.iconArrowDown,
          iconArrowUp = _this$props.iconArrowUp,
          isOpen = _this$props.isOpen,
          props = _objectWithoutPropertiesLoose(_this$props, ["onClick", "iconArrowDown", "iconArrowUp", "isOpen"]);

      var classNames = this.classNames;
      return React.createElement("div", {
        className: CLASS_CONTAINER,
        onClick: onClick
      }, React.createElement(BaseComponent, Object.assign({}, props, {
        readOnly: true
      })), React.createElement("span", {
        className: classNames
      }, iconArrow));
    };

    _createClass(WithSelectUI, [{
      key: "classNames",
      get: function get() {
        var _cx;

        var isOpen = this.props.isOpen; // eslint-disable-line react/prop-types

        return cx(CLASS_ARROW, (_cx = {}, _cx[CLASS_ARROW_DOWN] = !isOpen, _cx[CLASS_ARROW_UP] = isOpen, _cx));
      }
    }]);

    return WithSelectUI;
  }(Component), _class.displayName = "withSelectUI(" + displayName + ")", _temp;
});

==> react-molecule-select-1.7.0.tgz: package/lib/hoc/withSelectUI.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _createClass from "@babel/runtime/helpers/createClass";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeSelect-inputSelect";
var CLASS_CONTAINER = BASE_CLASS + "-container";
var CLASS_ARROW = BASE_CLASS + "-arrow";
var CLASS_ARROW_DOWN = CLASS_ARROW + "--down";
var CLASS_ARROW_UP = CLASS_ARROW + "--up";
export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(WithSelectUI, _Component);

    function WithSelectUI() {
      return _Component.apply(this, arguments) || this;
    }

    var _proto = WithSelectUI.prototype;

    _proto.render = function render() {
      /* eslint-disable react/prop-types */
      var _this$props = this.props,
          onClick = _this$props.onClick,
          iconArrow = _this$props.iconArrowDown,
          iconArrowUp = _this$props.iconArrowUp,
          isOpen = _this$props.isOpen,
          disabled = _this$props.disabled,
          props = _objectWithoutPropertiesLoose(_this$props, ["onClick", "iconArrowDown", "iconArrowUp", "isOpen", "disabled"]);

      var classNames = this.classNames;
      return React.createElement("div", {
        className: CLASS_CONTAINER,
        onClick: !disabled && onClick
      }, React.createElement(BaseComponent, Object.assign({}, props, {
        disabled: true,
        readOnly: !disabled
      })), React.createElement("span", {
        className: classNames
      }, iconArrow));
    };

    _createClass(WithSelectUI, [{
      key: "classNames",
      get: function get() {
        var _cx;

        var isOpen = this.props.isOpen; // eslint-disable-line react/prop-types

        return cx(CLASS_ARROW, (_cx = {}, _cx[CLASS_ARROW_DOWN] = !isOpen, _cx[CLASS_ARROW_UP] = isOpen, _cx));
      }
    }]);

    return WithSelectUI;
  }(Component), _class.displayName = "withSelectUI(" + displayName + ")", _temp;
});
